@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=b44c41ad
+MEDIALIBRARY_HASH=7e2fe29
 
 RELEASE=0
 ASAN=0
@@ -501,6 +501,7 @@ gen_pc_file GLESv2 2
 
 cd contrib/contrib-android-${TARGET_TUPLE}
 
+export USE_FFMPEG=1
 ANDROID_ABI=${ANDROID_ABI} ANDROID_API=android-${ANDROID_API} \
     ../bootstrap --host=${TARGET_TUPLE} ${VLC_BOOTSTRAP_ARGS}
 checkfail "contribs: bootstrap failed"
@@ -516,8 +517,6 @@ echo "EXTRA_LDFLAGS=${EXTRA_LDFLAGS}" >> config.mak
 make $MAKEFLAGS fetch
 checkfail "contribs: make fetch failed"
 
-# We already have zlib available in the NDK
-[ -e .zlib ] || (mkdir -p zlib; touch .zlib)
 # gettext
 which autopoint >/dev/null || make $MAKEFLAGS .gettext
 #export the PATH
