@@ -40,7 +40,14 @@ init(JNIEnv* env, jobject thiz, jstring dbPath, jstring thumbsPath)
     return m_IsInitialized;
 }
 
-void release(JNIEnv* env, jobject thiz)
+void
+start(JNIEnv* env, jobject thiz)
+{
+    MediaLibrary_getInstance(env, thiz)->start();
+}
+
+void
+release(JNIEnv* env, jobject thiz)
 {
     LOGD("/!\\ release medialib. /!\\");
     AndroidMediaLibrary *aml = MediaLibrary_getInstance(env, thiz);
@@ -57,14 +64,16 @@ banFolder(JNIEnv* env, jobject thiz, jstring folderPath)
     env->ReleaseStringUTFChars(folderPath, path);
 }
 
-void addDevice(JNIEnv* env, jobject thiz, jstring uuid, jstring storagePath, jboolean removable)
+jboolean
+addDevice(JNIEnv* env, jobject thiz, jstring uuid, jstring storagePath, jboolean removable)
 {
     AndroidMediaLibrary *aml = MediaLibrary_getInstance(env, thiz);
     const char *uuidChar = env->GetStringUTFChars(uuid, JNI_FALSE);
     const char *path = env->GetStringUTFChars(storagePath, JNI_FALSE);
-    aml->addDevice(uuidChar, path, removable);
+    jboolean isNew = aml->addDevice(uuidChar, path, removable);
     env->ReleaseStringUTFChars(uuid, uuidChar);
     env->ReleaseStringUTFChars(storagePath, path);
+    return isNew;
 }
 
 jobjectArray
@@ -199,9 +208,8 @@ lastMediaPLayed(JNIEnv* env, jobject thiz)
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : mediaPlayed) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(mediaRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(mediaRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -249,9 +257,8 @@ getVideos(JNIEnv* env, jobject thiz)
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : videoFiles) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(videoRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(videoRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -267,9 +274,8 @@ getInternalAudio(JNIEnv* env, jobject thiz, medialibrary::SortingCriteria sort =
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : audioFiles) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(audioRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(audioRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -499,9 +505,7 @@ getPlaylist(JNIEnv* env, jobject thiz, jlong id)
 {
     AndroidMediaLibrary *aml = MediaLibrary_getInstance(env, thiz);
     medialibrary::PlaylistPtr playlist = aml->playlist(id);
-    if (playlist != nullptr)
-        return convertPlaylistObject(env, &ml_fields, playlist);
-    return nullptr;
+    return playlist != nullptr ? convertPlaylistObject(env, &ml_fields, playlist) : nullptr;
 }
 
 jobject
@@ -511,7 +515,7 @@ playlistCreate(JNIEnv* env, jobject thiz, jstring name)
     const char *name_cstr = env->GetStringUTFChars(name, JNI_FALSE);
     medialibrary::PlaylistPtr playlist = aml->PlaylistCreate(name_cstr);
     env->ReleaseStringUTFChars(name, name_cstr);
-    return convertPlaylistObject(env, &ml_fields, playlist);
+    return playlist != nullptr ? convertPlaylistObject(env, &ml_fields, playlist) : nullptr;
 }
 
 /*
@@ -529,9 +533,8 @@ getTracksFromAlbum(JNIEnv* env, jobject thiz, jobject medialibrary, jlong id)
     jobject item = nullptr;
     for(medialibrary::MediaPtr const& media : tracks) {
         item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(mediaRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(mediaRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -556,9 +559,8 @@ getMediaFromArtist(JNIEnv* env, jobject thiz, jobject medialibrary, jlong id)
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : mediaList) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(mediaRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(mediaRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -594,9 +596,8 @@ getMediaFromGenre(JNIEnv* env, jobject thiz, jobject medialibrary, jlong id)
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : mediaList) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(mediaRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(mediaRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -687,9 +688,8 @@ getMediaFromPlaylist(JNIEnv* env, jobject thiz, jobject medialibrary, jlong id)
     int index = -1, drops = 0;
     for(medialibrary::MediaPtr const& media : mediaList) {
         jobject item = mediaToMediaWrapper(env, &ml_fields, media);
-        if (item != nullptr)
-            env->SetObjectArrayElement(mediaRefs, ++index, item);
-        else
+        env->SetObjectArrayElement(mediaRefs, ++index, item);
+        if (item == nullptr)
             ++drops;
         env->DeleteLocalRef(item);
     }
@@ -750,8 +750,9 @@ playlistDelete(JNIEnv* env, jobject thiz, jobject medialibrary, jlong playlistId
 static JNINativeMethod methods[] = {
     {"nativeSetup", "()V", (void*)setup },
     {"nativeInit", "(Ljava/lang/String;Ljava/lang/String;)Z", (void*)init },
+    {"nativeStart", "()V", (void*)start },
     {"nativeRelease", "()V", (void*)release },
-    {"nativeAddDevice", "(Ljava/lang/String;Ljava/lang/String;Z)V", (void*)addDevice },
+    {"nativeAddDevice", "(Ljava/lang/String;Ljava/lang/String;Z)Z", (void*)addDevice },
     {"nativeDevices", "()[Ljava/lang/String;", (void*)devices },
     {"nativeDiscover", "(Ljava/lang/String;)V", (void*)discover },
     {"nativeRemoveEntryPoint", "(Ljava/lang/String;)V", (void*)removeEntryPoint },
