@@ -124,8 +124,6 @@ public class AWindow implements IVLCVout {
         }
 
         public void release() {
-            if (AndroidUtil.isICSOrLater() && mSurface != null)
-                mSurface.release();
             mSurface = null;
             setNativeSurface(mId, null);
             if (mSurfaceHolder != null)
@@ -189,7 +187,7 @@ public class AWindow implements IVLCVout {
         }
 
         private final TextureView.SurfaceTextureListener mSurfaceTextureListener =
-                AndroidUtil.isICSOrLater() ? createSurfaceTextureListener() : null;
+                AndroidUtil.isICSOrLater ? createSurfaceTextureListener() : null;
     }
 
     private final static int SURFACE_STATE_INIT = 0;
@@ -245,7 +243,7 @@ public class AWindow implements IVLCVout {
     }
 
     private void setView(int id, TextureView view) {
-        if (!AndroidUtil.isICSOrLater())
+        if (!AndroidUtil.isICSOrLater)
             throw new IllegalArgumentException("TextureView not implemented in this android version");
         ensureInitState();
         if (view == null)
@@ -390,7 +388,6 @@ public class AWindow implements IVLCVout {
 
     @MainThread
     private void onSurfaceDestroyed() {
-        Log.e("lala", "onSurfaceDestroyed");
         detachViews();
     }
 
@@ -544,7 +541,7 @@ public class AWindow implements IVLCVout {
      */
     @SuppressWarnings("unused") /* used by JNI */
     private boolean setBuffersGeometry(final Surface surface, final int width, final int height, final int format) {
-        if (AndroidUtil.isICSOrLater())
+        if (AndroidUtil.isICSOrLater)
             return false;
         if (width * height == 0)
             return false;
@@ -717,7 +714,7 @@ public class AWindow implements IVLCVout {
      */
     @SuppressWarnings("unused") /* used by JNI */
     static private SurfaceTextureThread SurfaceTextureThread_create(int texName) {
-        if (AndroidUtil.isICSOrLater()) {
+        if (AndroidUtil.isICSOrLater) {
             final SurfaceTextureThread st = new SurfaceTextureThread(texName);
             st.start();
             return st;
