@@ -74,6 +74,10 @@ public class Medialibrary {
         return mIsInitiated;
     }
 
+    public void start() {
+        nativeStart();
+    }
+
     public void banFolder(String path) {
         if (mIsInitiated && new File(path).exists())
             nativeBanFolder(Tools.encodeVLCMrl(path));
@@ -83,8 +87,8 @@ public class Medialibrary {
         return mIsInitiated ? nativeDevices() : new String[0];
     }
 
-    public void addDevice(String uuid, String path, boolean removable) {
-        nativeAddDevice(uuid, Tools.encodeVLCMrl(path), removable);
+    public boolean addDevice(String uuid, String path, boolean removable) {
+        return nativeAddDevice(uuid, Tools.encodeVLCMrl(path), removable);
     }
 
     public void discover(String path) {
@@ -536,9 +540,10 @@ public class Medialibrary {
     // Native methods
     private native void nativeSetup();
     private native boolean nativeInit(String dbPath, String thumbsPath);
+    private native void nativeStart();
     private native void nativeRelease();
     private native void nativeBanFolder(String path);
-    private native void nativeAddDevice(String uuid, String path, boolean removable);
+    private native boolean nativeAddDevice(String uuid, String path, boolean removable);
     private native String[] nativeDevices();
     private native void nativeDiscover(String path);
     private native void nativeRemoveEntryPoint(String path);
