@@ -7,17 +7,16 @@ import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
-import android.content.SharedPreferences;
 import android.net.Uri;
 import android.os.Binder;
 import android.os.IBinder;
 import android.os.PowerManager;
-import android.preference.PreferenceManager;
 import android.support.annotation.Nullable;
 import android.support.v4.app.NotificationCompat;
 import android.support.v4.app.NotificationManagerCompat;
 import android.support.v4.content.LocalBroadcastManager;
 import android.text.TextUtils;
+import android.util.Log;
 
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.interfaces.DevicesDiscoveryCb;
@@ -25,9 +24,13 @@ import org.videolan.vlc.gui.DialogActivity;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.Strings;
-import org.videolan.vlc.util.Util;
 
 import java.io.File;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
 
 public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     public final static String TAG = "VLC/MediaParsingService";
@@ -43,15 +46,21 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     public final static String ACTION_RESUME_SCAN = "action_resume_scan";
     public final static String ACTION_PAUSE_SCAN = "action_pause_scan";
+    public final static String ACTION_SERVICE_STARTED = "action_service_started";
+    public final static String ACTION_SERVICE_ENDED = "action_service_ended";
     public static final long NOTIFICATION_DELAY = 1000L;
     private PowerManager.WakeLock mWakeLock;
 
+    private volatile boolean initOngoing = false;
     private final IBinder mBinder = new LocalBinder();
     private Medialibrary mMedialibrary;
     private int mParsing = 0, mReload = 0;
     private String mCurrentDiscovery = null;
     private long mLastNotificationTime = 0L;
 
+    private final ThreadPoolExecutor mThreadPool = new ThreadPoolExecutor(1, 1, 30, TimeUnit.SECONDS,
+            new LinkedBlockingQueue<Runnable>(), VLCApplication.THREAD_FACTORY);
+
     private BroadcastReceiver mReceiver = new BroadcastReceiver() {
         @Override
         public void onReceive(Context context, Intent intent) {
@@ -107,31 +116,40 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                 setupMedialibrary(intent.getBooleanExtra(StartActivity.EXTRA_UPGRADE, false));
                 break;
             case ACTION_RELOAD:
-                reload();
+                reload(intent.getStringExtra(EXTRA_PATH));
                 break;
             case ACTION_DISCOVER:
                 discover(intent.getStringExtra(EXTRA_PATH));
                 break;
             case ACTION_DISCOVER_DEVICE:
-                discoverStorage(intent.getStringExtra(EXTRA_PATH), intent.getStringExtra(EXTRA_UUID));
+                discoverStorage(intent.getStringExtra(EXTRA_PATH));
                 break;
         }
+        LocalBroadcastManager.getInstance(this).sendBroadcast(new Intent(ACTION_SERVICE_STARTED));
         return START_NOT_STICKY;
     }
 
-    private void discoverStorage(String path, String uuid) {
-        if (!TextUtils.isEmpty(uuid))
-            mMedialibrary.addDevice(uuid, path, true);
-        for (String folder : Medialibrary.getBlackList())
-            mMedialibrary.banFolder(path + folder);
-        mMedialibrary.discover(path);
+    private void discoverStorage(final String path) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "discoverStorage: "+path);
+        mThreadPool.execute(new Runnable() {
+            @Override
+            public void run() {
+                for (String folder : Medialibrary.getBlackList())
+                    mMedialibrary.banFolder(path + folder);
+                mMedialibrary.discover(path);
+            }
+        });
     }
 
-    private void discover(String path) {
+    private void discover(final String path) {
         if (TextUtils.isEmpty(path))
             return;
-        addDeviceIfNeeded(path);
-        mMedialibrary.discover(path);
+        mThreadPool.execute(new Runnable() {
+            @Override
+            public void run() {
+                mMedialibrary.discover(path);
+            }
+        });
     }
 
     private void addDeviceIfNeeded(String path) {
@@ -147,48 +165,53 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
         }
     }
 
-    private void reload() {
+    private void reload(String path) {
         if (mReload > 0)
             return;
-        mMedialibrary.reload();
+        if (TextUtils.isEmpty(path))
+            mMedialibrary.reload();
+        else
+            mMedialibrary.reload(path);
     }
 
     private void setupMedialibrary(final boolean upgrade) {
         if (mMedialibrary.isInitiated())
             mMedialibrary.resumeBackgroundOperations();
         else
-            VLCApplication.runBackground(new Runnable() {
+            mThreadPool.execute(new Runnable() {
                 @Override
                 public void run() {
-                    mMedialibrary.setup();
+                    initOngoing = true;
                     boolean shouldInit = !(new File(MediaParsingService.this.getCacheDir()+Medialibrary.VLC_MEDIA_DB_NAME).exists());
-                    String[] storages = AndroidDevices.getMediaDirectories();
-                    for (String storage : storages) {
-                        boolean isMainStorage = TextUtils.equals(storage, AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
-                        mMedialibrary.addDevice(isMainStorage ? "main-storage" : FileUtils.getFileNameFromPath(storage), storage, !isMainStorage);
-                    }
+                    mMedialibrary.setup();
                     if (mMedialibrary.init(MediaParsingService.this)) {
-                        LocalBroadcastManager.getInstance(MediaParsingService.this).sendBroadcast(new Intent(VLCApplication.ACTION_MEDIALIBRARY_READY));
-                        if (shouldInit) {
-                            for (String folder : Medialibrary.getBlackList())
-                                mMedialibrary.banFolder(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + folder);
-                            mMedialibrary.discover(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
-                        } else if (upgrade) {
-                            mMedialibrary.forceParserRetry();
-                        }
-                        final String[] foldersList = mMedialibrary.getFoldersList();
-                        final SharedPreferences mSettings = PreferenceManager.getDefaultSharedPreferences(MediaParsingService.this);
-                        for (String externalStorage : AndroidDevices.getExternalStorageDirectories()) {
-                            if (!TextUtils.equals(externalStorage, AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY)
-                                    && !Util.arrayContains(foldersList, "file://" + externalStorage + "/")
-                                    && !mSettings.getBoolean("ignore_"+FileUtils.getFileNameFromPath(externalStorage), false)) {
-                                startActivity(new Intent(MediaParsingService.this, DialogActivity.class)
-                                        .setAction(DialogActivity.KEY_STORAGE)
-                                        .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
-                                        .putExtra(EXTRA_PATH, externalStorage));
+                        List<String> devices = new ArrayList<>();
+                        devices.add(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
+                        devices.addAll(AndroidDevices.getExternalStorageDirectories());
+                        for (String device : devices) {
+                            boolean isMainStorage = TextUtils.equals(device, AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
+                            boolean isNew = mMedialibrary.addDevice(isMainStorage ? "main-storage" : FileUtils.getFileNameFromPath(device), device, !isMainStorage);
+                            if (isMainStorage) {
+                                if (shouldInit) {
+                                    for (String folder : Medialibrary.getBlackList())
+                                        mMedialibrary.banFolder(device + folder);
+                                }
+                            } else if (isNew) {
+                                    startActivity(new Intent(MediaParsingService.this, DialogActivity.class)
+                                            .setAction(DialogActivity.KEY_STORAGE)
+                                            .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
+                                            .putExtra(EXTRA_PATH, device));
                             }
+
                         }
+                        mMedialibrary.start();
+                        LocalBroadcastManager.getInstance(MediaParsingService.this).sendBroadcast(new Intent(VLCApplication.ACTION_MEDIALIBRARY_READY));
+                        if (shouldInit)
+                            mMedialibrary.discover(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
+                        else if (upgrade)
+                            mMedialibrary.forceParserRetry();
                     }
+                    initOngoing = false;
                 }
             });
     }
@@ -253,22 +276,27 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     }
 
     @Override
-    public void onDiscoveryStarted(String entryPoint) {}
+    public void onDiscoveryStarted(String entryPoint) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "onDiscoveryStarted: "+entryPoint);
+    }
 
     @Override
     public void onDiscoveryProgress(String entryPoint) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "onDiscoveryProgress: "+entryPoint);
         mCurrentDiscovery = entryPoint;
         showNotification();
     }
 
     @Override
     public void onDiscoveryCompleted(String entryPoint) {
-        if (!mMedialibrary.isWorking())
+        if (BuildConfig.DEBUG) Log.d(TAG, "onDiscoveryCompleted: "+entryPoint);
+        if (!initOngoing && !mMedialibrary.isWorking())
             stopSelf();
     }
 
     @Override
     public void onParsingStatsUpdated(int percent) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "onParsingStatsUpdated: "+percent);
         mParsing = percent;
         if (mParsing == 100)
             stopSelf();
@@ -278,20 +306,23 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     @Override
     public void onReloadStarted(String entryPoint) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "onReloadStarted: "+entryPoint);
         if (TextUtils.isEmpty(entryPoint))
             ++mReload;
     }
 
     @Override
     public void onReloadCompleted(String entryPoint) {
+        if (BuildConfig.DEBUG) Log.d(TAG, "onReloadCompleted "+entryPoint);
         if (TextUtils.isEmpty(entryPoint))
             --mReload;
-        if (!mMedialibrary.isWorking())
+        if (!initOngoing && !mMedialibrary.isWorking())
             stopSelf();
     }
 
     @Override
     public void onDestroy() {
+        LocalBroadcastManager.getInstance(this).sendBroadcast(new Intent(ACTION_SERVICE_ENDED));
         hideNotification();
         mMedialibrary.removeDeviceDiscoveryCb(this);
         unregisterReceiver(mReceiver);
