@@ -76,6 +76,7 @@ import org.videolan.vlc.gui.browser.ExtensionBrowser;
 import org.videolan.vlc.gui.browser.FileBrowserFragment;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
+import org.videolan.vlc.gui.dialogs.AdvOptionsDialog;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.network.MRLPanelFragment;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
@@ -120,6 +121,7 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
 
     private Menu mMenu;
     private SearchView mSearchView;
+    private boolean mFirstRun, mUpgrade;
 
     // Extensions management
     private ServiceConnection mExtensionServiceConnection;
@@ -184,6 +186,8 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         mDrawerLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);
 
         if (getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false)) {
+            mUpgrade = true;
+            mFirstRun = getIntent().getBooleanExtra(StartActivity.EXTRA_FIRST_RUN, false);
             /*
              * The sliding menu is automatically opened when the user closes
              * the info dialog. If (for any reason) the dialog is not shown,
@@ -223,7 +227,10 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 // If request is cancelled, the result arrays are empty.
                 if (grantResults.length > 0
                         && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
-                    startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
+                    Intent serviceIntent = new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class);
+                    serviceIntent.putExtra(StartActivity.EXTRA_FIRST_RUN, mFirstRun);
+                    serviceIntent.putExtra(StartActivity.EXTRA_UPGRADE, mUpgrade);
+                    startService(serviceIntent);
                 } else
                     Permissions.showStoragePermissionDialog(this, false);
                 break;
@@ -437,8 +444,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 return new FileBrowserFragment();
             case R.id.nav_history:
                 return new HistoryFragment();
-            case R.id.nav_mrl:
-                return new MRLPanelFragment();
             case R.id.nav_network:
                 return new NetworkBrowserFragment();
             default:
@@ -818,6 +823,9 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 case R.id.nav_settings:
                     startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
                     break;
+                case R.id.nav_mrl:
+                    new MRLPanelFragment().show(getSupportFragmentManager(), "fragment_mrl");
+                    break;
                 case R.id.nav_directories:
                     if (TextUtils.equals(BuildConfig.FLAVOR_target, "chrome")) {
                         Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
