@@ -30,6 +30,7 @@ import android.content.IntentFilter;
 import android.content.pm.PackageManager;
 import android.graphics.Bitmap;
 import android.graphics.drawable.Drawable;
+import android.net.Uri;
 import android.os.AsyncTask;
 import android.os.Build;
 import android.os.Bundle;
@@ -58,7 +59,6 @@ import org.videolan.libvlc.Media;
 import org.videolan.libvlc.MediaPlayer;
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.Tools;
-import org.videolan.medialibrary.interfaces.DevicesDiscoveryCb;
 import org.videolan.medialibrary.interfaces.MediaUpdatedCb;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.BuildConfig;
@@ -86,7 +86,7 @@ import java.util.List;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
 public class MainTvActivity extends BaseTvActivity implements OnItemViewSelectedListener,
-        OnItemViewClickedListener, OnClickListener, PlaybackService.Callback, MediaUpdatedCb, DevicesDiscoveryCb {
+        OnItemViewClickedListener, OnClickListener, PlaybackService.Callback, MediaUpdatedCb {
 
     private static final int NUM_ITEMS_PREVIEW = 5;
 
@@ -169,7 +169,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         /*
          * skip browser and show directly Audio Player if a song is playing
          */
-        if (mMediaLibrary.isInitiated() && (mRowsAdapter == null || mRowsAdapter.size() == 0) && Permissions.canReadStorage())
+        if (mMediaLibrary.isInitiated() && !mMediaLibrary.isWorking() && (mRowsAdapter == null || mRowsAdapter.size() == 0) && Permissions.canReadStorage())
             update();
         else {
             updateBrowsers();
@@ -213,7 +213,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mService.addCallback(this);
         if (mMediaLibrary.isInitiated()) {
             setmedialibraryListeners();
-            update();
         } else
             setupMediaLibraryReceiver();
     }
@@ -224,7 +223,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         if (mService != null)
             mService.removeCallback(this);
         mMediaLibrary.removeMediaUpdatedCb();
-        mMediaLibrary.removeDeviceDiscoveryCb(this);
     }
 
     @Override
@@ -370,30 +368,13 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     }
 
     @Override
-    public void onDiscoveryStarted(String entryPoint) {}
-
-    @Override
-    public void onDiscoveryProgress(String entryPoint) {}
-
-    @Override
-    public void onDiscoveryCompleted(String entryPoint) {}
-
-    @Override
-    public void onParsingStatsUpdated(int percent) {
-        if (percent == 100)
-            update();
-        else if (mProgressBar.getVisibility() != View.VISIBLE)
-            mHandler.sendEmptyMessage(SHOW_LOADING);
+    protected void onParsingServiceStarted() {
+        mHandler.sendEmptyMessageDelayed(SHOW_LOADING, 300);
     }
 
     @Override
-    public void onReloadStarted(String entryPoint) {
-            mHandler.sendEmptyMessage(SHOW_LOADING);
-    }
-
-    @Override
-    public void onReloadCompleted(String entryPoint) {
-            mHandler.sendEmptyMessage(HIDE_LOADING);
+    protected void onParsingServiceFinished() {
+        update();
     }
 
     private static final int SHOW_LOADING = 0;
@@ -414,7 +395,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         }
     };
 
-    public class AsyncUpdate extends AsyncTask<Void, Void, Void> {
+    private class AsyncUpdate extends AsyncTask<Void, Void, Void> {
         boolean showHistory;
         MediaWrapper[] history, videoList;
 
@@ -426,7 +407,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             if (mRowsAdapter != null)
                 mRowsAdapter.clear();
             mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
-            mHandler.sendEmptyMessage(SHOW_LOADING);
+            mHandler.sendEmptyMessageDelayed(SHOW_LOADING, 300);
             mHistoryIndex.clear();
 
             //Video Section
@@ -552,11 +533,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         updateBrowsers();
     }
 
-    @Override
-    protected void onExternelDeviceChange() {
-        updateBrowsers();
-    }
-
     @Override
     public void updateProgress(){}
 
@@ -588,7 +564,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         } else  if (mService.hasMedia()){
             MediaWrapper mw = mService.getCurrentMediaWrapper();
             String display = MediaUtils.getMediaTitle(mw) + " - " + MediaUtils.getMediaReferenceArtist(MainTvActivity.this, mw);
-            Bitmap cover = AudioUtil.getCover(MainTvActivity.this, mw, VLCApplication.getAppResources().getDimensionPixelSize(R.dimen.grid_card_thumb_width));
+            Bitmap cover = AudioUtil.readCoverBitmap(Uri.decode(mw.getArtworkMrl()), VLCApplication.getAppResources().getDimensionPixelSize(R.dimen.grid_card_thumb_width));
             if (mNowPlayingCard == null) {
                 if (cover != null)
                     mNowPlayingCard = new CardPresenter.SimpleCard(MusicFragment.CATEGORY_NOW_PLAYING, display, cover);
@@ -610,7 +586,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     private void setmedialibraryListeners() {
         mMediaLibrary.setMediaUpdatedCb(this, Medialibrary.FLAG_MEDIA_UPDATED_VIDEO);
-        mMediaLibrary.addDeviceDiscoveryCb(this);
     }
 
     private void setupMediaLibraryReceiver() {
