@@ -22,10 +22,7 @@ package org.videolan.vlc.gui.video;
 
 import android.annotation.TargetApi;
 import android.app.Activity;
-import android.content.BroadcastReceiver;
-import android.content.Context;
 import android.content.Intent;
-import android.content.IntentFilter;
 import android.content.SharedPreferences;
 import android.content.res.Configuration;
 import android.content.res.Resources;
@@ -35,7 +32,6 @@ import android.os.Handler;
 import android.os.Message;
 import android.preference.PreferenceManager;
 import android.support.annotation.MainThread;
-import android.support.v4.content.LocalBroadcastManager;
 import android.support.v7.view.ActionMode;
 import android.support.v7.widget.DividerItemDecoration;
 import android.support.v7.widget.RecyclerView;
@@ -55,7 +51,6 @@ import android.widget.TextView;
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.medialibrary.Medialibrary;
-import org.videolan.medialibrary.interfaces.DevicesDiscoveryCb;
 import org.videolan.medialibrary.interfaces.MediaAddedCb;
 import org.videolan.medialibrary.interfaces.MediaUpdatedCb;
 import org.videolan.medialibrary.media.MediaLibraryItem;
@@ -82,7 +77,7 @@ import org.videolan.vlc.util.VLCInstance;
 import java.util.ArrayList;
 import java.util.List;
 
-public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, DevicesDiscoveryCb, MediaAddedCb, Filterable, IEventsHandler {
+public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, MediaAddedCb, Filterable, IEventsHandler {
 
     public final static String TAG = "VLC/VideoListFragment";
 
@@ -132,20 +127,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         return v;
     }
 
-    @Override
-    public void onViewCreated(View view, Bundle savedInstanceState) {
-        super.onViewCreated(view, savedInstanceState);
-
-        // init the information for the scan (2/2)
-        IntentFilter filter = new IntentFilter();
-        filter.addAction(MediaUtils.ACTION_SCAN_START);
-        filter.addAction(MediaUtils.ACTION_SCAN_STOP);
-        LocalBroadcastManager.getInstance(getActivity()).registerReceiver(messageReceiverVideoListFragment, filter);
-        if (mMediaLibrary.isWorking()) {
-            MediaUtils.actionScanStart();
-        }
-    }
-
 
     public void onStart() {
         super.onStart();
@@ -159,7 +140,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         setSearchVisibility(false);
         updateViewMode();
         if (mMediaLibrary.isInitiated())
-            fillView();
+            onMedialibraryReady();
         else if (mGroup == null)
             setupMediaLibraryReceiver();
     }
@@ -167,7 +148,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
     @Override
     public void onPause() {
         super.onPause();
-        mMediaLibrary.removeDeviceDiscoveryCb(this);
         mMediaLibrary.removeMediaUpdatedCb();
         mMediaLibrary.removeMediaAddedCb();
     }
@@ -184,23 +164,17 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         outState.putString(KEY_GROUP, mGroup);
     }
 
-    @Override
-    public void onDestroyView() {
-        LocalBroadcastManager.getInstance(getActivity()).unregisterReceiver(messageReceiverVideoListFragment);
-        super.onDestroyView();
-    }
-
     @Override
     public void onDestroy() {
         super.onDestroy();
         mVideoAdapter.clear();
     }
 
-    protected void fillView() {
+    protected void onMedialibraryReady() {
+        super.onMedialibraryReady();
         if (mGroup == null) {
             mMediaLibrary.setMediaUpdatedCb(this, Medialibrary.FLAG_MEDIA_UPDATED_VIDEO);
             mMediaLibrary.setMediaAddedCb(this, Medialibrary.FLAG_MEDIA_ADDED_VIDEO);
-            mMediaLibrary.addDeviceDiscoveryCb(this);
         }
         mHandler.sendEmptyMessage(UPDATE_LIST);
     }
@@ -428,19 +402,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         mGroup = prefix;
     }
 
-    private final BroadcastReceiver messageReceiverVideoListFragment = new BroadcastReceiver() {
-        @Override
-        public void onReceive(Context context, Intent intent) {
-            String action = intent.getAction();
-
-            if (action.equalsIgnoreCase(MediaUtils.ACTION_SCAN_START)) {
-                mLayoutFlipperLoading.setVisibility(View.VISIBLE);
-            } else if (action.equalsIgnoreCase(MediaUtils.ACTION_SCAN_STOP)) {
-                mLayoutFlipperLoading.setVisibility(View.INVISIBLE);
-            }
-        }
-    };
-
     @Override
     public void onRefresh() {
         getActivity().startService(new Intent(MediaParsingService.ACTION_RELOAD, null, getActivity(), MediaParsingService.class));
@@ -458,35 +419,14 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         super.setFabPlayVisibility(!mVideoAdapter.isEmpty() && enable);
     }
 
-    boolean mParsing = false;
     @Override
-    public void onDiscoveryStarted(String entryPoint) {}
-
-    @Override
-    public void onDiscoveryProgress(String entryPoint) {}
-
-    @Override
-    public void onDiscoveryCompleted(final String entryPoint) {
-        mHandler.sendEmptyMessage(mParsing ? SET_REFRESHING : UNSET_REFRESHING);
+    protected void onParsingServiceStarted() {
+        mHandler.sendEmptyMessageDelayed(SET_REFRESHING, 300);
     }
 
     @Override
-    public void onParsingStatsUpdated(final int percent) {
-        mParsing = percent < 100;
-        if (percent == 100)
-            mHandler.sendEmptyMessage(UPDATE_LIST);
-        else if (!mSwipeRefreshLayout.isRefreshing())
-            mHandler.sendEmptyMessage(SET_REFRESHING);
-    }
-
-    @Override
-    public void onReloadStarted(String entryPoint) {
-            mHandler.sendEmptyMessage(SET_REFRESHING);
-    }
-
-    @Override
-    public void onReloadCompleted(String entryPoint) {
-            mHandler.sendEmptyMessage(UNSET_REFRESHING);
+    protected void onParsingServiceFinished() {
+        mHandler.sendEmptyMessage(UPDATE_LIST);
     }
 
     @Override
